summaryrefslogtreecommitdiff
path: root/vcl
diff options
context:
space:
mode:
authorRüdiger Timm <rt@openoffice.org>2003-05-02 13:36:32 +0000
committerRüdiger Timm <rt@openoffice.org>2003-05-02 13:36:32 +0000
commit2d23971bbb940390e6cc8e198f4ddbcecab25419 (patch)
tree39cb3da28fee7bdfa20ebbfb8edffc23ddd2234f /vcl
parent9445c2c634251121f3a95400a150e71136c538b9 (diff)
INTEGRATION: CWS beta2regression03 (1.41.6); FILE MERGED
2003/04/30 15:02:09 hdu 1.41.6.1: #i13779# fix off by one in GetNextGlyphs()
Diffstat (limited to 'vcl')
-rwxr-xr-xvcl/source/gdi/sallayout.cxx17
1 files changed, 10 insertions, 7 deletions
diff --git a/vcl/source/gdi/sallayout.cxx b/vcl/source/gdi/sallayout.cxx
index 3ed884e3b7a1..4eae41f50178 100755
--- a/vcl/source/gdi/sallayout.cxx
+++ b/vcl/source/gdi/sallayout.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: sallayout.cxx,v $
*
- * $Revision: 1.41 $
+ * $Revision: 1.42 $
*
- * last change: $Author: rt $ $Date: 2003-04-24 10:27:30 $
+ * last change: $Author: rt $ $Date: 2003-05-02 14:36:32 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -1100,14 +1100,17 @@ int GenericSalLayout::GetNextGlyphs( int nLen, long* pGlyphs, Point& rPos,
if( ++nStart >= mnGlyphCount )
break;
- // stop when x-position is unexpected
- long nXPos = pG->maLinearPos.X();
- ++pG;
+ // stop when next x-position is unexpected
if( !pGlyphAdvAry )
- if( pG->mnOrigWidth != (pG->maLinearPos.X() - nXPos) )
+ {
+ long nNextXPos = pG[1].maLinearPos.X();
+ if( pG->mnOrigWidth != (nNextXPos - pG->maLinearPos.X()) )
break;
+ }
+
+ ++pG;
- // stop when y-position is unexpected
+ // stop when next y-position is unexpected
if( nYPos != pG->maLinearPos.Y() )
break;